@@ -7,7 +7,7 @@ from tornado.web import UIModule
 class CSS(UIModule):
     def render(self, origin, compress=None, *args, **kwargs):
         cdn = self.handler.cdn
-        debug = self.handler.debug
+        debug = self.handler.css_debug
 
         css_version = self.handler.css_version
 
